//#############################################################################
//
//  File:   f2802x_examples_ccsv4/adc_soc/Example_F2802xAdcSoc.c
//
//  Title:  F2802x ADC Start-Of-Conversion (SOC) Example Program.
//
//  Group:          C2000
//  Target Device:  TMS320F2802x
//
//! \addtogroup example_list
//!  <h1>ADC Start-Of-Conversion (SOC)</h1>
//!
//!   Interrupts are enabled and the ePWM1 is setup to generate a periodic
//!   ADC SOC - ADCINT1. Two channels are converted, ADCINA4 and ADCINA2.
//!
//!   Watch Variables:
//!
//!   - Voltage1[10] - Last 10 ADCRESULT0 values
//!   - Voltage2[10] - Last 10 ADCRESULT1 values
//!   - ConversionCount - Current result number 0-9
//!   - LoopCount - Idle loop counter
//
//  (C) Copyright 2012, Texas Instruments, Inc.
//#############################################################################
// $TI Release: f2802x Support Library v200 $
// $Release Date: Tue Jul 24 10:01:39 CDT 2012 $
//#############################################################################

#include "DSP28x_Project.h"     // Device Headerfile and Examples Include File
#include "F2802x_Device.h"     // Headerfile Include File
#include "f2802x_common/include/F2802x_Examples.h"   // Examples Include File
#include "f2802x_common/source/F2802x_Adc.c"
#include "f2802x_common/include/adc.h"
#include "f2802x_common/include/clk.h"
#include "f2802x_common/include/flash.h"
#include "f2802x_common/include/gpio.h"
#include "f2802x_common/include/pie.h"
#include "f2802x_common/include/pll.h"
#include "f2802x_common/include/wdog.h"
#include "f2802x_common/include/spi.h"
#include "f2802x_common/include/timer.h"
#include "string.h"
#include "Sytem_5x7.h"

#define LCD_CS_SET     GPIO_setHigh(myGpio, GPIO_Number_0);//LCD CS
#define LCD_CS_CLEAR   GPIO_setLow(myGpio, GPIO_Number_0);
#define LCD_RST_SET    GPIO_setHigh(myGpio, GPIO_Number_1);//LCD RST
#define LCD_RST_CLEAR  GPIO_setLow(myGpio, GPIO_Number_1);
#define LCD_RS_SET     GPIO_setHigh(myGpio, GPIO_Number_2);//LCD RS
#define LCD_RS_CLEAR   GPIO_setLow(myGpio, GPIO_Number_2);
#define adc_cycles     100
#define LCD_FONT System_5x7

// Prototype statements for functions found within this file.
interrupt void adc_isr(void);
void Adc_Config(void);
// Prototype statements for functions found within this file.
interrupt void cpu_timer0_isr(void);
interrupt void cpu_timer1_isr(void);
//timer section
unsigned long timer0IntCount=0;
unsigned long timer1IntCount=0;

// Global variables used in this example:
uint16_t LoopCount;
uint16_t ConversionCount;
uint16_t Voltage1[10];
uint16_t Voltage2[10];

char solar_voltage[10]="";
char solar_current[10]="";
char motor_voltage[10]="";
char motor_current[10]="";

//timer 0 1 2
char timer0 [10]="";
char timer1 [10]="";
char timer2 [10]="";

ADC_Handle myAdc;
CLK_Handle myClk;
FLASH_Handle myFlash;
GPIO_Handle myGpio;
PIE_Handle myPie;
PWM_Handle myPwm;
SPI_Handle mySpi;
TIMER_Handle myTimer0, myTimer1, myTimer2;

void ADC_Init(void);

void spi_init(void);
void spi_fifo_init(void);

void LCD_write_cmd(unsigned char lcdcommand);
void LCD_write_data(unsigned char lcddata);
void LCD_init();
void LCD_setXY(unsigned char x1, unsigned char x2, unsigned char y1, unsigned char y2);
void LCD_clrXY();
void LCD_display_char_5x7(unsigned char x, unsigned char y, unsigned char dp, unsigned char fontcolor, unsigned char backgroundcolor, unsigned char fontscale);
void LCD_display_string_5x7(unsigned char x, unsigned char y, char *dp, unsigned char fontcolor, unsigned char backgroundcolor, unsigned char fontscale);
void LCD_clrScr();

char* itoa(int value, char* result, int base);
void dtos(double input_num,int precision,char * string);
char clear_str(char * input);

double d_result_A1;
double d_result_B1;
double d_result_A3;
double d_result_B3;

char ADC_result_A1(void);
char ADC_result_B1(void);
char ADC_result_A3(void);
char ADC_result_B3(void);

int16_t ADC_Channel_A1(void);
int16_t ADC_Channel_B1(void);
int16_t ADC_Channel_A3(void);
int16_t ADC_Channel_B3(void);
//test
unsigned char readdata=0;

uint16_t rdata;

void main(void)
{

    CPU_Handle myCpu;
    PLL_Handle myPll;
    WDOG_Handle myWDog;

    // Initialize all the handles needed for this application
    myClk = CLK_init((void *)CLK_BASE_ADDR, sizeof(CLK_Obj));
    myCpu = CPU_init((void *)NULL, sizeof(CPU_Obj));
    myFlash = FLASH_init((void *)FLASH_BASE_ADDR, sizeof(FLASH_Obj));
    myGpio = GPIO_init((void *)GPIO_BASE_ADDR, sizeof(GPIO_Obj));
    myPie = PIE_init((void *)PIE_BASE_ADDR, sizeof(PIE_Obj));
    myPll = PLL_init((void *)PLL_BASE_ADDR, sizeof(PLL_Obj));
    mySpi = SPI_init((void *)SPIA_BASE_ADDR, sizeof(SPI_Obj));
    myPwm = PWM_init((void *)PWM_ePWM1_BASE_ADDR, sizeof(PWM_Obj));
    myWDog = WDOG_init((void *)WDOG_BASE_ADDR, sizeof(WDOG_Obj));
    myTimer0 = TIMER_init((void *)TIMER0_BASE_ADDR, sizeof(TIMER_Obj));
    myTimer1 = TIMER_init((void *)TIMER1_BASE_ADDR, sizeof(TIMER_Obj));

    // Perform basic system initialization
    WDOG_disable(myWDog);
    CLK_enableAdcClock(myClk);
    (*Device_cal)();

    //Select the internal oscillator 1 as the clock source
    CLK_enableTbClockSync(myClk);

    CLK_setOscSrc(myClk, CLK_OscSrc_Internal);

    // Setup the PLL for x10 /2 which will yield 50Mhz = 10Mhz * 10 / 2
    PLL_setup(myPll, PLL_Multiplier_10, PLL_DivideSelect_ClkIn_by_2);

    // Disable the PIE and all interrupts
    PIE_disable(myPie);
    PIE_disableAllInts(myPie);
    CPU_disableGlobalInts(myCpu);
    CPU_clearIntFlags(myCpu);

// If running from flash copy RAM only functions to RAM
#ifdef _FLASH
    memcpy(&RamfuncsRunStart, &RamfuncsLoadStart, (size_t)&RamfuncsLoadSize);
#endif
    GPIO_setDirection(myGpio, GPIO_Number_0, GPIO_Direction_Output);
    	GPIO_setDirection(myGpio, GPIO_Number_1, GPIO_Direction_Output);
    	GPIO_setDirection(myGpio, GPIO_Number_2, GPIO_Direction_Output);

    	GPIO_setMode(myGpio, GPIO_Number_0, GPIO_0_Mode_GeneralPurpose);
    	GPIO_setMode(myGpio, GPIO_Number_1, GPIO_1_Mode_GeneralPurpose);
    	GPIO_setMode(myGpio, GPIO_Number_2, GPIO_2_Mode_GeneralPurpose);

    	GPIO_setPullUp(myGpio, GPIO_Number_16, GPIO_PullUp_Enable);
    	GPIO_setPullUp(myGpio, GPIO_Number_17, GPIO_PullUp_Enable);
    	GPIO_setPullUp(myGpio, GPIO_Number_18, GPIO_PullUp_Enable);

    	GPIO_setQualification(myGpio, GPIO_Number_16, GPIO_Qual_ASync);
    	GPIO_setQualification(myGpio, GPIO_Number_17, GPIO_Qual_ASync);
    	GPIO_setQualification(myGpio, GPIO_Number_18, GPIO_Qual_ASync);

    	GPIO_setMode(myGpio, GPIO_Number_16, GPIO_16_Mode_SPISIMOA);
    	GPIO_setMode(myGpio, GPIO_Number_17, GPIO_17_Mode_SPISOMIA);
    	GPIO_setMode(myGpio, GPIO_Number_18, GPIO_18_Mode_SPICLKA);

    // Setup a debug vector table and enable the PIE
    PIE_setDebugIntVectorTable(myPie);
    PIE_enable(myPie);

    // Register interrupt handlers in the PIE vector table
    //timer interrupt
        PIE_registerPieIntHandler(myPie, PIE_GroupNumber_1, PIE_SubGroupNumber_7, (intVec_t)&cpu_timer0_isr);
        PIE_registerSystemIntHandler(myPie, PIE_SystemInterrupts_TINT1, (intVec_t)&cpu_timer1_isr);

        PIE_enableInt(myPie, PIE_GroupNumber_1, PIE_InterruptSource_XINT_1);
        GPIO_setMode(myGpio, GPIO_Number_12, GPIO_12_Mode_GeneralPurpose);
        GPIO_setDirection(myGpio, GPIO_Number_12, GPIO_Direction_Input);
        GPIO_setQualification(myGpio, GPIO_Number_12, GPIO_Qual_Sync);
        GPIO_setExtInt(myGpio, GPIO_Number_12, CPU_ExtIntNumber_1);
        PIE_setExtIntPolarity(myPie, CPU_ExtIntNumber_1, PIE_ExtIntPolarity_RisingEdge);
        PIE_enableExtInt(myPie, CPU_ExtIntNumber_1);
        //   InitCpuTimers();
        TIMER_stop(myTimer0);
        TIMER_stop(myTimer1);

        TIMER_setPeriod(myTimer0, 50 * 1000000);
        TIMER_setPeriod(myTimer1, 50 * 1000000);
        //
        TIMER_setPreScaler(myTimer0, 0);
        TIMER_reload(myTimer0);
        TIMER_setEmulationMode(myTimer0, TIMER_EmulationMode_StopAfterNextDecrement);
        TIMER_enableInt(myTimer0);

        TIMER_setPreScaler(myTimer1, 0);
        TIMER_reload(myTimer1);
        TIMER_setEmulationMode(myTimer1, TIMER_EmulationMode_StopAfterNextDecrement);
        TIMER_enableInt(myTimer1);


        //   CpuTimer0Regs.TCR.all = 0x4001; // Use write-only instruction to set TSS bit = 0
            TIMER_start(myTimer0);
        //   CpuTimer1Regs.TCR.all = 0x4001; // Use write-only instruction to set TSS bit = 0
            TIMER_start(myTimer1);
        //    IER |= M_INT1;
            CPU_enableInt(myCpu, CPU_IntNumber_1);
        //    IER |= M_INT13;
            CPU_enableInt(myCpu, CPU_IntNumber_13);
        // Enable TINT0 in the PIE: Group 1 interrupt 7
        //   PieCtrlRegs.PIEIER1.bit.INTx7 = 1;
            PIE_enableTimer0Int(myPie);
        // Enable global Interrupts and higher priority real-time debug events:
        //    EINT;   // Enable Global interrupt INTM
            CPU_enableGlobalInts(myCpu);
        //    ERTM;   // Enable Global realtime interrupt DBGM
            CPU_enableDebugInt(myCpu);
        //


    //SPI initialization
    spi_init();
    spi_fifo_init();
    DELAY_US(1000);
    //LCD initialization
    LCD_init();
    LCD_clrScr();
    // Enabled ADCINT1 and ADCINT2
    ADC_Init();
    // Wait for ADC interrupt
    for(;;)
    {
        ADC_result_A1();   //convert in voltage
        ADC_result_B1();   //convert in CURRENT
        ADC_result_A3();   //convert in voltage
        ADC_result_B3();   //convert in CURRENT

        LCD_display_string_5x7(0,0, "Solar Voltage:", 0xFFFF, 0x0000, 2);
        LCD_display_string_5x7(167,0,solar_voltage, 0xFFFF, 0x0000, 2);
        LCD_display_string_5x7(263,0,"V", 0xFFFF, 0x0000, 2);

        LCD_display_string_5x7(0,29, "Solar Current:", 0xFFFF, 0x0000, 2);
        LCD_display_string_5x7(167,29,solar_current, 0xFFFF, 0x0000, 2);
         LCD_display_string_5x7(262,29,"A", 0xFFFF, 0x0000, 2);

         LCD_display_string_5x7(0,58, "Motor Voltage:", 0xFFFF, 0x0000, 2);
         LCD_display_string_5x7(167,58,motor_voltage, 0xFFFF, 0x0000, 2);
         LCD_display_string_5x7(263,58,"V", 0xFFFF, 0x0000, 2);

         LCD_display_string_5x7(0,87, "Motor Current:", 0xFFFF, 0x0000, 2);
         LCD_display_string_5x7(167,87,motor_current, 0xFFFF, 0x0000, 2);
          LCD_display_string_5x7(263,87,"A", 0xFFFF, 0x0000, 2);

    }
// INTERRUPT
}
interrupt void cpu_timer0_isr(void)
{
    	timer0IntCount++;
    // Acknowledge this interrupt to receive more interrupts from group 1
//   PieCtrlRegs.PIEACK.all = PIEACK_GROUP1;
    PIE_clearInt(myPie, PIE_GroupNumber_1);
}

interrupt void cpu_timer1_isr(void)
{
	timer1IntCount++;
}
/*---------------------------------------ADC CONVERSION-------------------------------------------------*/

/*---------------------------------------ADC CONVERSION-------------------------------------------------*/
void spi_init()
{
	CLK_enableSpiaClock(myClk);
	SPI_setCharLength(mySpi, SPI_CharLength_8_Bits);
	SPI_setMode(mySpi, SPI_Mode_Master);
	SPI_setClkPhase(mySpi, SPI_ClkPhase_Delayed);
	SPI_enableTx(mySpi);
	SPI_setBaudRate(mySpi, SPI_BaudRate_1_MBaud);
	SPI_enable(mySpi);
	SPI_setPriority(mySpi, SPI_Priority_FreeRun);
	return;
}
/*--------------------------------------SPI SECTION----------------------------------------------*/
void spi_fifo_init()
{
	SPI_enableChannels(mySpi);
	SPI_enableFifoEnh(mySpi);
	SPI_resetTxFifo(mySpi);
	SPI_clearTxFifoInt(mySpi);
	SPI_resetRxFifo(mySpi);
	SPI_clearRxFifoInt(mySpi);
	SPI_setRxFifoIntLevel(mySpi, SPI_FifoLevel_4_Words);
	return;
}
/*--------------------------------------END OF SPI SECTION----------------------------------------------*/

////////////////////////////////////////////LCD SECTION///////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////
void LCD_write_cmd(unsigned char lcdcommand)
{
	if(GPIO_getData(myGpio, GPIO_Number_2) == 1)
	{
		LCD_RS_CLEAR;
	}
	SPI_write(mySpi, lcdcommand<<8);
	while(SPI_getRxFifoStatus(mySpi) == SPI_FifoStatus_Empty){}
	rdata = SPI_read(mySpi);
}

void LCD_write_data(unsigned char lcddata)
{
	if(GPIO_getData(myGpio, GPIO_Number_2) == 0)
	{
		LCD_RS_SET;
	}
	SPI_write(mySpi, lcddata<<8);
    while(SPI_getRxFifoStatus(mySpi) == SPI_FifoStatus_Empty){}
    rdata = SPI_read(mySpi);
}

void LCD_init()
{
	LCD_CS_CLEAR;
	LCD_RST_CLEAR;
	DELAY_US(1000);
	LCD_RST_SET;
	DELAY_US(1000);

    LCD_write_cmd(0xCB);
    LCD_write_data(0x39);
    LCD_write_data(0x2C);
    LCD_write_data(0x00);
    LCD_write_data(0x34);
    LCD_write_data(0x02);

    LCD_write_cmd(0xCF);
    LCD_write_data(0x00);
    LCD_write_data(0XC1);
    LCD_write_data(0X30);

    LCD_write_cmd(0xE8);
    LCD_write_data(0x85);
    LCD_write_data(0x00);
    LCD_write_data(0x78);

    LCD_write_cmd(0xEA);
    LCD_write_data(0x00);
    LCD_write_data(0x00);

    LCD_write_cmd(0xED);
    LCD_write_data(0x64);
    LCD_write_data(0x03);
    LCD_write_data(0X12);
    LCD_write_data(0X81);

    LCD_write_cmd(0xF7);
    LCD_write_data(0x20);

    LCD_write_cmd(0xC0);    //Power control
    LCD_write_data(0x23);   //VRH[5:0]

    LCD_write_cmd(0xC1);    //Power control
    LCD_write_data(0x10);   //SAP[2:0];BT[3:0]

    LCD_write_cmd(0xC5);    //VCM control
    LCD_write_data(0x3e);   //Contrast
    LCD_write_data(0x28);

    LCD_write_cmd(0xC7);    //VCM control2
    LCD_write_data(0x86);   //--

    LCD_write_cmd(0x36);    // Memory Access Control
    LCD_write_data(0x48);

    LCD_write_cmd(0x3A);
    LCD_write_data(0x55);

    LCD_write_cmd(0xB1);
    LCD_write_data(0x00);
    LCD_write_data(0x18);

    LCD_write_cmd(0xB6);    // Display Function Control
    LCD_write_data(0x08);
    LCD_write_data(0x82);
    LCD_write_data(0x27);

    LCD_write_cmd(0x11);    //Exit Sleep
    DELAY_US(120000);

    LCD_write_cmd(0x29);    //Display on
    LCD_write_cmd(0x2c);
}

void LCD_setXY(unsigned char x1, unsigned char x2, unsigned char y1, unsigned char y2)
{
	LCD_write_cmd(0x2a);
	LCD_write_data(y1>>8);
	LCD_write_data(y1);
	LCD_write_data(y2>>8);
	LCD_write_data(y2);

	LCD_write_cmd(0x2b);
	LCD_write_data(319-x2>>8);
	LCD_write_data(319-x2);
	LCD_write_data(319-x1>>8);
	LCD_write_data(319-x1);

	LCD_write_cmd(0x2c);
}

void LCD_clrXY()
{
  LCD_setXY(0, 319, 0, 239);
}

void LCD_display_char_5x7(unsigned char x,unsigned char y,unsigned char dp, unsigned char fontcolor, unsigned char backgroundcolor, unsigned char fontscale)
{
	long i;
	long j;
	long k;
	long l;
	unsigned char fontbtye;

	if(fontscale==1)
	{
		LCD_setXY(x, x+4, y, y+6);
		for(i=0; i<5; i++)
		{
			fontbtye = (LCD_FONT[dp-32][4-i]);
			for(j=0; j<7; j++)
			{
				if((fontbtye & (1<<j)) != 0)
				{
					LCD_write_data(fontcolor>>8);
					LCD_write_data(fontcolor);
				}
				else
				{
					LCD_write_data(backgroundcolor>>8);
					LCD_write_data(backgroundcolor);
				}
			}
		}
	}
	else
	{
		LCD_setXY(x, x+(5*fontscale)-1, y, y+(7*fontscale)-1);
		for(i=0; i<5; i++)
		{
			fontbtye = (LCD_FONT[dp-32][4-i]);
			for(j=0; j<fontscale; j++)
			{
				for(k=0; k<7; k++)
				{
					if((fontbtye & (1<<k)) != 0)
					{
						for(l=0; l<fontscale; l++)
						{
							LCD_write_data(fontcolor>>8);
							LCD_write_data(fontcolor);
						}
					}
					else
					{
						for(l=0; l<fontscale; l++)
						{
						LCD_write_data(backgroundcolor>>8);
						LCD_write_data(backgroundcolor);
						}
					}
				}
			}
		}
	}
}

void LCD_display_string_5x7(unsigned char x, unsigned char y, char *dp, unsigned char fontcolor, unsigned char backgroundcolor, unsigned char fontscale)
{
	LCD_display_char_5x7(x, y, *dp++, fontcolor, backgroundcolor, fontscale);
	while(*dp!='\0')
	{
		LCD_display_char_5x7(x+=6*fontscale, y, *dp++, fontcolor, backgroundcolor, fontscale);
	}
}

void LCD_clrScr()
{
	long i;

	LCD_clrXY();
	for(i=0; i<76800; i++)
	{
		LCD_write_data(0x0000>>8);
		LCD_write_data(0x0000);
	}
}
///////////////////////////////////END OF LCD SECTION//////////////////////////////////////////////////////
/*--------------------------------------DATA CONVERSION-------------------------------------------------*/
//Integer to String
char* itoa(int value, char* result, int base)
{
	if (base < 2 || base > 36) { *result = '\0'; return result; }
	char* ptr = result, *ptr1 = result, tmp_char;
	int tmp_value;
	do
	{
		tmp_value = value;
		value /= base;
		*ptr++ = "zyxwvutsrqponmlkjihgfedcba9876543210123456789abcdefghijklmnopqrstuvwxyz" [35 + (tmp_value - value * base)];
	} while ( value );
	if (tmp_value < 0) *ptr++ = '-';
	*ptr-- = '\0';
	while(ptr1 < ptr)
	{
		tmp_char = *ptr;
		*ptr--= *ptr1;
		*ptr1++ = tmp_char;
	}
	return result;
}
//Double to String Array
void dtos(double input_num,int precision,char *to_string)
{
	char temp[50]="",temp1[50]="",k=0;
	int i=0,b=0;
	double z;
	unsigned long y;
	if(input_num<0)
	{
		temp[k]='-';
		input_num=0-input_num;
		k++;
    }
	y=(unsigned long)input_num;
    z=input_num-y;
    if(y)
    {
    	while(y)
    	{
    		temp1[b]=y%10+0x30;
    		y/=10;
    		b++;
      }
    }
    else temp1[0]=0+0x30;
    b=strlen(temp1);
    for(i=0;i<strlen(temp1);i++,k++,b--)
    temp[k]=temp1[b-1];
    for(i=0;i<50;i++)
    temp1[i]=0;
    k=0;
    i=0;
    temp1[k]='.';
    k++;
    while(i!=precision+1)
    {
    	z=z*10;
    	y=(int)(z);
    	z-=y;
    	temp1[k]=y+0x30;
    	k++;
    	i++;
    }
    temp1[strlen(temp1)-1]='\0';
    strcat(temp,temp1);
    strcat(to_string,temp);
    return;
}
//function to clear the data in a string
char clear_str(char * string)
{
	int i=0;
    while(string[i]!='\0')
    {
    	string[i]=0;
    	i++;
    }
	return(*string);
}
/*----------------------------------END OF DATA CONVERSION----------------------------------------------*/
void ADC_Init()
{
	myAdc = ADC_init((void *)ADC_BASE_ADDR, sizeof(ADC_Obj));
	ADC_enableBandGap(myAdc);
    ADC_enableRefBuffers(myAdc);
    ADC_powerUp(myAdc);
    ADC_enable(myAdc);
	ADC_setVoltRefSrc(myAdc, ADC_VoltageRefSrc_Int);
	// Configure ADC
	//Connect channel A4
	ADC_setSocChanNumber (myAdc, ADC_SocNumber_0, ADC_SocChanNumber_A1);//Set SOC0 channel select to ADCINA4
	ADC_setSocChanNumber (myAdc, ADC_SocNumber_1, ADC_SocChanNumber_A1);//Set SOC1 channel select to ADCINA4
	ADC_setSocSampleWindow(myAdc, ADC_SocNumber_0, ADC_SocSampleWindow_7_cycles);//Set SOC0 acquisition period to 7 ADCCLK
	ADC_setSocSampleWindow(myAdc, ADC_SocNumber_1, ADC_SocSampleWindow_7_cycles);//Set SOC1 acquisition period to 7 ADCCLK
	ADC_setIntSrc(myAdc, ADC_IntNumber_1, ADC_IntSrc_EOC1);//Connect ADCINT1 to EOC1
	ADC_enableInt(myAdc, ADC_IntNumber_1);//Enable ADCINT1
		//Connect channel A2
	ADC_setSocChanNumber (myAdc, ADC_SocNumber_2, ADC_SocChanNumber_B1);//Set SOC4 channel select to ADCINB4
	ADC_setSocChanNumber (myAdc, ADC_SocNumber_3, ADC_SocChanNumber_B1);//Set SOC5 channel select to ADCINB4
	ADC_setSocSampleWindow(myAdc, ADC_SocNumber_2, ADC_SocSampleWindow_7_cycles);//Set SOC4 acquisition period to 7 ADCCLK
	ADC_setSocSampleWindow(myAdc, ADC_SocNumber_3, ADC_SocSampleWindow_7_cycles);//Set SOC5 acquisition period to 7 ADCCLK
	ADC_setIntSrc(myAdc, ADC_IntNumber_3, ADC_IntSrc_EOC3);//Connect ADCINT5 to EOC5
	ADC_enableInt(myAdc, ADC_IntNumber_3);//Enable ADCINT3
	//Connect channel A2
	ADC_setSocChanNumber (myAdc, ADC_SocNumber_4, ADC_SocChanNumber_A3);//Set SOC4 channel select to ADCINB4
	ADC_setSocChanNumber (myAdc, ADC_SocNumber_5, ADC_SocChanNumber_A3);//Set SOC5 channel select to ADCINB4
	ADC_setSocSampleWindow(myAdc, ADC_SocNumber_4, ADC_SocSampleWindow_7_cycles);//Set SOC4 acquisition period to 7 ADCCLK
	ADC_setSocSampleWindow(myAdc, ADC_SocNumber_5, ADC_SocSampleWindow_7_cycles);//Set SOC5 acquisition period to 7 ADCCLK
	ADC_setIntSrc(myAdc, ADC_IntNumber_5, ADC_IntSrc_EOC5);//Connect ADCINT5 to EOC5
	ADC_enableInt(myAdc, ADC_IntNumber_5);//Enable ADCINT3
	//Connect channel A2
	ADC_setSocChanNumber (myAdc, ADC_SocNumber_6, ADC_SocChanNumber_B3);//Set SOC4 channel select to ADCINB4
	ADC_setSocChanNumber (myAdc, ADC_SocNumber_7, ADC_SocChanNumber_B3);//Set SOC5 channel select to ADCINB4
	ADC_setSocSampleWindow(myAdc, ADC_SocNumber_6, ADC_SocSampleWindow_7_cycles);//Set SOC4 acquisition period to 7 ADCCLK
	ADC_setSocSampleWindow(myAdc, ADC_SocNumber_7, ADC_SocSampleWindow_7_cycles);//Set SOC5 acquisition period to 7 ADCCLK
	ADC_setIntSrc(myAdc, ADC_IntNumber_7, ADC_IntSrc_EOC7);//Connect ADCINT5 to EOC5
	ADC_enableInt(myAdc, ADC_IntNumber_7);//Enable ADCINT3
}
/*---------------------------------------ADC CONVERSION-------------------------------------------------*/
//Get ADC result channel A4
char ADC_result_A1(){
    clear_str(solar_voltage);
	unsigned long adc_results_arr[adc_cycles+1]={0};
	unsigned long adc_sum=0;
	unsigned int adc_mean=0;
	int i;
		for (i=0;i<(adc_cycles);i++)
		{
			adc_results_arr[i]= ADC_Channel_A1();
		}
		for (i=0;i<(adc_cycles);i++)
		{
			adc_sum+=adc_results_arr[i];
		}
		adc_mean=adc_sum/adc_cycles;
    d_result_A1 = (3.3*adc_mean)/4096;
    dtos(d_result_A1,4,solar_voltage);
    return 0;
}

//Get ADC result channel A2
char ADC_result_B1()
{
    clear_str(solar_current);
    unsigned long adc_results_arr[adc_cycles+1]={0};
    unsigned long adc_sum=0;
    unsigned int adc_mean=0;
    int i;
    		for (i=0;i<(adc_cycles);i++)
    		{
    			adc_results_arr[i]= ADC_Channel_B1();
    		}
    		for (i=0;i<(adc_cycles);i++)
    		{
    			adc_sum+=adc_results_arr[i];
    		}
    		adc_mean=adc_sum/adc_cycles;
    d_result_B1 = (3.3*adc_mean)/4096;
    d_result_B1=(d_result_B1-2.5152)*10000/125;
    dtos(d_result_B1,4,solar_current);
    return 0;
}

char ADC_result_A3(){
    clear_str(motor_voltage);
    unsigned long adc_results_arr[adc_cycles+1]={0};
    unsigned long adc_sum=0;
    unsigned int adc_mean=0;
    int i;
    		for (i=0;i<(adc_cycles);i++)
    		{
    			adc_results_arr[i]= ADC_Channel_A3();
    		}
    		for (i=0;i<(adc_cycles);i++)
    		{
    			adc_sum+=adc_results_arr[i];
    		}
    		adc_mean=adc_sum/adc_cycles;
    d_result_A3 = (3.3*adc_mean)/4096;
    dtos(d_result_A3,4,motor_voltage);
    return 0;
}

char ADC_result_B3()
{
    clear_str(motor_current);
    unsigned long adc_results_arr[adc_cycles+1]={0};
    unsigned long adc_sum=0;
    unsigned int adc_mean=0;
    int i;
    		for (i=0;i<(adc_cycles);i++)
    		{
    			adc_results_arr[i]= ADC_Channel_B3();
    		}
    		for (i=0;i<(adc_cycles);i++)
    		{
    			adc_sum+=adc_results_arr[i];
    		}
    		adc_mean=adc_sum/adc_cycles;
    d_result_B3 = (3.3*adc_mean)/4096;
    d_result_B3 =(d_result_B3-2.5175)*80;
    dtos(d_result_B3,2,motor_current);
    return 0;
}

//Start ADC Convertion
int16_t ADC_Channel_A1(void){
    //Force start of conversion on SOC0 and SOC1
    ADC_forceConversion(myAdc, ADC_SocNumber_0);
    ADC_forceConversion(myAdc, ADC_SocNumber_1);
    //Wait for end of conversion.
    while(ADC_getIntStatus(myAdc, ADC_IntNumber_1) == 0) {
    }
    // Clear ADCINT1
    ADC_clearIntFlag(myAdc, ADC_IntNumber_1);
    return (ADC_readResult(myAdc, ADC_ResultNumber_1));
}
int16_t ADC_Channel_B1(void){
    //Force start of conversion on SOC0 and SOC1
    ADC_forceConversion(myAdc, ADC_SocNumber_2);
    ADC_forceConversion(myAdc, ADC_SocNumber_3);
    //Wait for end of conversion.
    while(ADC_getIntStatus(myAdc, ADC_IntNumber_3) == 0) {
    }
    // Clear ADCINT1
    ADC_clearIntFlag(myAdc, ADC_IntNumber_3);
    return (ADC_readResult(myAdc, ADC_ResultNumber_3));
}
int16_t ADC_Channel_A3(void){
    //Force start of conversion on SOC0 and SOC1
    ADC_forceConversion(myAdc, ADC_SocNumber_4);
    ADC_forceConversion(myAdc, ADC_SocNumber_5);
    //Wait for end of conversion.
    while(ADC_getIntStatus(myAdc, ADC_IntNumber_5) == 0) {
    }
    // Clear ADCINT1
    ADC_clearIntFlag(myAdc, ADC_IntNumber_5);
    return (ADC_readResult(myAdc, ADC_ResultNumber_5));
}
int16_t ADC_Channel_B3(void){
    //Force start of conversion on SOC0 and SOC1
    ADC_forceConversion(myAdc, ADC_SocNumber_6);
    ADC_forceConversion(myAdc, ADC_SocNumber_7);
    //Wait for end of conversion.
    while(ADC_getIntStatus(myAdc, ADC_IntNumber_7) == 0) {
    }
    // Clear ADCINT1
    ADC_clearIntFlag(myAdc, ADC_IntNumber_7);
    return (ADC_readResult(myAdc, ADC_ResultNumber_7));
}
/*---------------------------------------ADC CONVERSION-------------------------------------------------*/

